import hljs from 'highlight.js'

export const slugify = (str: string) =>
  str
    .trim()
    .toString()
    .toLowerCase()
    .replace(/\s+/g, '-')
    .replace(/\+/g, '-p')
    .replace(/#/g, '-sharp')
    .replace(/[^\w\-]+/g, '')

export const shorten = (name: string) => {
  let n = slugify(name).replace('script', '-s').replace('python', 'py').replace('markdown', 'md')
  const nov = (s: string) => s[0] + s.substring(1).replace(/[aeiouy-]/g, '')
  if (n.replace(/-/g, '').length <= 4) {
    return n.replace(/-/g, '')
  }
  if (n.split('-').length >= 2) {
    return n
      .split('-')
      .map((x) => nov(x.substring(0, 2)))
      .join('')
      .substring(0, 4)
  }
  n = nov(n)
  if (n.length <= 4) {
    return n
  }
  return n.substring(0, 2) + n.substring(n.length - 2, 2)
}

export function getLangFromUrl() {
  return new URLSearchParams(window.location.search).get('l') ?? 'plt'
}

export const byId = (id: string) => document.getElementById(id)

export function isInIframe(): boolean {
  return window !== window.parent
}

export function getHljsLangFromShort(short: string): string {
  const langs = hljs
    .listLanguages()
    .filter((l) => l !== 'taggerscript') // seriously? This overrides typescript.
    .map((lang) => ({ lang, short: shorten(lang) }))
  return langs.find((l) => l.short === short)?.lang ?? 'plaintext'
}
